@@ -34,7 +34,6 @@
 /* Header files */
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_DIRENT_H 1
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FPU_CONTROL_H 1
@@ -116,7 +115,6 @@
 #define HAVE_PREAD 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
 #define HAVE_PTHREAD_SIGMASK 1
-#define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 /* #undef HAVE_SETFD */
@@ -193,7 +191,6 @@
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_ABI_CXA_DEMANGLE */
-#define HAVE_BSS_START 1
 #define HAVE_BUILTIN_UNREACHABLE 1
 #define HAVE_BUILTIN_EXPECT 1
 #define HAVE_BUILTIN_STPCPY 1
@@ -255,7 +252,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.16-10/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.16-10/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.16-10/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.17-11/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.17-11/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.17-11/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -391,15 +388,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 16
-#define MYSQL_VERSION_EXTRA "-10"
+#define MYSQL_VERSION_PATCH 17
+#define MYSQL_VERSION_EXTRA "-11"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.16-10"
+#define PACKAGE_STRING "MySQL Server 5.7.17-11"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.16-10"
-#define VERSION "5.7.16-10"
+#define PACKAGE_VERSION "5.7.17-11"
+#define VERSION "5.7.17-11"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -449,7 +446,6 @@
 #define DEFAULT_SECURE_FILE_PRIV_DIR "NULL"
 #define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
 /* #undef HAVE_LIBNUMA */
-#define WITH_NUMA 1
 
 /* For default value of --early_plugin_load */
 /* #undef DEFAULT_EARLY_PLUGIN_LOAD */
